# packages/sms/tcl/sms-procs.tcl

ad_library {
    
    SMS Procedures
    
    @author Malte Sussdorff (<malte@openacs.de>)
    @creation-date 2007-01-14
    @cvs-id $Id: sms-procs.tcl,v 1.1 2007/01/14 11:31:45 maltes Exp $
}

namespace eval sms {}

ad_proc -public sms::clean_phone_number {
    -phone_number
    {-package_id ""}
} {
    
    This procedure will take a phone number and strip it from "+",
    leading 0 and whitespace, so we can have a clean phone number
    which can be used for posting around.

    @author Malte Sussdorff (malte.sussdorff@cognovis.de)
    @creation-date 2007-01-14
    
    @param phone_number Number to be cleaned

    @param package_id Package_id to use

    @return Phone number cleaned up with the prefix in front
    
    @error 
} {

    if {$package_id eq ""} {
	set package_id [ad_conn package_id]
    }
    
    # Strip out the prefix, so we don't have it twice
    set prefix [parameter::get -package_id $package_id -parameter Prefix]
    set phone_number [string trimleft $phone_number $prefix]

    # Strip out the "+" sign
    regsub -all {\+} $phone_number {} phone_number

    # Strip out (), which are being used to mark e.g. area codes
    regsub -all {\(} $phone_number {} phone_number
    regsub -all {\)} $phone_number {} phone_number

    # Strip out any whitespace
    regsub -all { } $phone_number {} phone_number

    return "${prefix}$phone_number"
}

